anova_nls: ANOVA Table for the Best NLS Model

View source: R/DryingKineticModels.R

anova_nlsR Documentation

ANOVA Table for the Best NLS Model

Description

Computes and prints a regression ANOVA table for a fitted nonlinear least squares model.

Usage

anova_nls(best_model, dat)

Arguments

best_model

A model result list (the success = TRUE list returned by any fit_*() function).

dat

A data frame with columns time and MR.

Value

A data frame containing the ANOVA table with columns Source, Sum of Squares, df, Mean Square, F Value, and Pr(>F). The table is also printed to the console.


dryingkineticmodels documentation built on July 21, 2026, 5:09 p.m.