View source: R/DryingKineticModels.R
| compare_models | R Documentation |
Computes goodness-of-fit statistics for all successfully fitted models and returns a ranked comparison table.
compare_models(results)
results |
A named list of model results as returned by
|
A data frame with one row per successfully fitted model
(models with R^2 \le 0 are excluded), sorted by a composite
rank score based on R^2, RMSE, and \chi^2. Columns are:
Model name.
Equation of the model.
Coefficient of determination.
Root mean square error.
Mean absolute error.
Reduced chi-squared statistic.
Residual sum of squares.
Parameter estimates as a character string.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.