View source: R/DryingKineticModels.R
| grid_search_fit_2stage | R Documentation |
Performs a coarse grid search over a parameter grid and returns the
best-fitting nonlinear least squares model using nlsLM.
grid_search_fit_2stage(
formula,
data,
param_grid,
control = minpack.lm::nls.lm.control(maxiter = 200)
)
formula |
A nonlinear model formula. |
data |
A data frame containing the variables in |
param_grid |
A named list of numeric vectors defining the grid of starting values for each parameter. |
control |
Control parameters passed to
|
The best-fitting nls object, or NULL if all
starting value combinations failed to converge.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.