| get_best_model | R Documentation |
Identifies the top-ranked model from the comparison table, prints its coefficients, fit statistics, hypothesis test results, and runs residual diagnostics.
get_best_model(results, comparison, dat, verbose = FALSE)
results |
A named list of model results as returned by
|
comparison |
A data frame as returned by |
dat |
A data frame with columns |
verbose |
Logical. If |
The model result list for the best model (the
success = TRUE list returned by the corresponding
fit_*() function).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.